@@ -1,5 +1,6 @@
 /* opencdk.h - Open Crypto Development Kit (OpenCDK)
- *        Copyright (C) 2001, 2002, 2003 Timo Schulz
+ *        Copyright (C) 2006 Free Software Foundation, Inc.
+ *        Copyright (C) 2001, 2002, 2003, 2005 Timo Schulz
  *
  * This file is part of OpenCDK.
  *
@@ -15,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with OpenCDK; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef OPENCDK_H
@@ -23,7 +24,7 @@
 
 #include <stdarg.h>
 
-#define OPENCDK_VERSION "0.5.2-cvs"
+#define OPENCDK_VERSION "0.5.13"
 
 #ifdef __cplusplus
 extern "C" {
@@ -112,7 +113,7 @@ typedef enum {
     CDK_Wrong_Format = 22,
     CDK_Inv_Packet_Ver = 23,
     CDK_Too_Short = 24,
-    CDK_Unusable_Key = 25,
+    CDK_Unusable_Key = 25
 } cdk_error_t;
 
 
@@ -129,8 +130,7 @@ enum cdk_control_flags {
     CDK_CTL_KEYCACHE_ON   = 17,
     CDK_CTL_KEYCACHE_FREE = 18,
     CDK_CTL_FORCE_DIGEST  = 19,
-    CDK_CTL_TRUSTMODEL    = 20,
-    CDK_CTL_BLOCKMODE_ON  = 21,
+    CDK_CTL_TRUSTMODEL    = 20
 };
 
 enum cdk_log_level_t {
@@ -161,7 +161,7 @@ enum cdk_md_algo_t {
     CDK_MD_RMD160  = 3,
     CDK_MD_MD2     = 5,
     CDK_MD_TIGER   = 6, /* will be removed and thus: reserved */
-    CDK_MD_SHA256  = 8,
+    CDK_MD_SHA256  = 8
 };
 
 enum cdk_cipher_algo_t {
@@ -175,7 +175,7 @@ enum cdk_cipher_algo_t {
     CDK_CIPHER_AES         = 7,
     CDK_CIPHER_AES192      = 8,
     CDK_CIPHER_AES256      = 9,
-    CDK_CIPHER_TWOFISH     = 10,
+    CDK_CIPHER_TWOFISH     = 10
 };
 
 enum cdk_s2k_type_t {
@@ -229,12 +229,12 @@ enum cdk_armor_type_t {
     CDK_ARMOR_PUBKEY    = 1,
     CDK_ARMOR_SECKEY    = 2,
     CDK_ARMOR_SIGNATURE = 3,
-    CDK_ARMOR_CLEARSIG  = 4,
+    CDK_ARMOR_CLEARSIG  = 4
 };
 
 enum cdk_stream_control_t {
     CDK_STREAMCTL_DISABLE    = 2,
-    CDK_STREAMCTL_COMPRESSED = 3,
+    CDK_STREAMCTL_COMPRESSED = 3
 };
 
 enum cdk_keydb_flag_t {
@@ -267,7 +267,8 @@ enum cdk_key_flag_t {
     CDK_KEY_VALID   = 0,
     CDK_KEY_INVALID = 1, /* missing or wrong self signature */
     CDK_KEY_EXPIRED = 2,
-    CDK_KEY_REVOKED = 4
+    CDK_KEY_REVOKED = 4,
+    CDK_KEY_NOSIGNER= 8
 };
 
 enum cdk_trust_flag_t {
@@ -312,11 +313,11 @@ enum cdk_attribute_t {
     CDK_ATTR_MPI      = 11,
     CDK_ATTR_NAME     = 12,
     CDK_ATTR_FPR      = 13,
-    CDK_ATTR_URL      = 14,
+    CDK_ATTR_URL      = 14, 
     /* cdk key flags */
     CDK_FLAG_KEY_REVOKED = 256,
     CDK_FLAG_KEY_EXPIRED = 512,
-    CDK_FLAG_SIG_EXPIRED = 1024,  
+    CDK_FLAG_SIG_EXPIRED = 1024
 };
 
 
@@ -345,7 +346,7 @@ typedef enum {
     CDK_PKT_OLD_COMMENT   = 16,
     CDK_PKT_ATTRIBUTE     = 17,
     CDK_PKT_ENCRYPTED_MDC = 18,
-    CDK_PKT_MDC           = 19,
+    CDK_PKT_MDC           = 19
 } cdk_packet_type_t;
 
 #define CDK_PKT_IS_ENCRYPTED(pkttype) (\
@@ -353,60 +354,28 @@ typedef enum {
   || ((pkttype)==CDK_PKT_ENCRYPTED) \
   )
 
-
-struct cdk_pkt_signature_s {
-    unsigned char version;
-    unsigned char sig_class;
-    unsigned long timestamp;
-    unsigned long expiredate;
-    unsigned long keyid[2];
-    unsigned char pubkey_algo;
-    unsigned char digest_algo;
-    unsigned char digest_start[2];
-    unsigned short hashed_size;
-    cdk_subpkt_t hashed;
-    unsigned short unhashed_size;
-    cdk_subpkt_t unhashed;
-    cdk_mpi_t mpi[2];
-    cdk_desig_revoker_t revkeys;
-    struct {
-        unsigned exportable:1;
-        unsigned revocable:1;
-        unsigned policy_url:1;
-        unsigned notation:1;
-        unsigned expired:1;
-        unsigned checked:1;
-        unsigned valid:1;
-        unsigned missing_key:1;
-    } flags;
-    unsigned long key[2]; /* only valid for key signatures */
-};
-typedef struct cdk_pkt_signature_s *cdk_pkt_signature_t;
-
-
 struct cdk_pkt_userid_s {
-    unsigned long len;
+    unsigned int len;
     unsigned is_primary:1;
     unsigned is_revoked:1;
     unsigned mdc_feature:1;
     cdk_prefitem_t prefs;
-    size_t prefs_size;
     unsigned char * attrib_img; /* Tag 17 if not null */
     size_t attrib_len;
-    cdk_pkt_signature_t selfsig;
-    char name[1];  
+    size_t prefs_size;
+    unsigned int created;
+    char name[1];
 };
 typedef struct cdk_pkt_userid_s *cdk_pkt_userid_t;
 
-
 struct cdk_pkt_pubkey_s {
     unsigned char version;
     unsigned char pubkey_algo;
     unsigned char fpr[20];
-    unsigned long keyid[2];
-    unsigned long main_keyid[2];
-    unsigned long timestamp;
-    unsigned long expiredate;
+    unsigned int keyid[2];
+    unsigned int main_keyid[2];
+    unsigned int timestamp;
+    unsigned int expiredate;
     cdk_mpi_t mpi[4];
     unsigned is_revoked:1;
     unsigned is_invalid:1;
@@ -421,11 +390,11 @@ typedef struct cdk_pkt_pubkey_s *cdk_pkt_pubkey_t;
 
 struct cdk_pkt_seckey_s {
     cdk_pkt_pubkey_t pk;
-    unsigned long expiredate;
+    unsigned int expiredate;
     int version;
     int pubkey_algo;
-    unsigned long keyid[2];
-    unsigned long main_keyid[2];
+    unsigned int keyid[2];
+    unsigned int main_keyid[2];
     unsigned char s2k_usage;
     struct {
         unsigned char algo;
@@ -445,12 +414,38 @@ struct cdk_pkt_seckey_s {
 };
 typedef struct cdk_pkt_seckey_s *cdk_pkt_seckey_t;
 
-
-
+struct cdk_pkt_signature_s {
+    unsigned char version;
+    unsigned char sig_class;
+    unsigned int timestamp;
+    unsigned int expiredate;
+    unsigned int keyid[2];
+    unsigned char pubkey_algo;
+    unsigned char digest_algo;
+    unsigned char digest_start[2];
+    unsigned short hashed_size;
+    cdk_subpkt_t hashed;
+    unsigned short unhashed_size;
+    cdk_subpkt_t unhashed;
+    cdk_mpi_t mpi[2];
+    cdk_desig_revoker_t revkeys;
+    struct {
+        unsigned exportable:1;
+        unsigned revocable:1;
+        unsigned policy_url:1;
+        unsigned notation:1;
+        unsigned expired:1;
+        unsigned checked:1;
+        unsigned valid:1;
+        unsigned missing_key:1;
+    } flags;  
+    unsigned int key[2]; /* only valid for key signatures */
+};
+typedef struct cdk_pkt_signature_s *cdk_pkt_signature_t;
 
 struct cdk_pkt_onepass_sig_s {
     unsigned char version;
-    unsigned long keyid[2];
+    unsigned int keyid[2];
     unsigned char sig_class;
     unsigned char digest_algo;
     unsigned char pubkey_algo;
@@ -461,7 +456,7 @@ typedef struct cdk_pkt_onepass_sig_s * cdk_pkt_onepass_sig_t;
 
 struct cdk_pkt_pubkey_enc_s {
     unsigned char version;
-    unsigned long keyid[2];
+    unsigned int keyid[2];
     int throw_keyid;
     unsigned char pubkey_algo;
     cdk_mpi_t mpi[2];
@@ -480,7 +475,7 @@ typedef struct cdk_pkt_symkey_enc_s *cdk_pkt_symkey_enc_t;
 
 
 struct cdk_pkt_encrypted_s {
-    unsigned long len;
+    unsigned int len;
     int extralen;
     unsigned char mdc_method;
     cdk_stream_t buf;
@@ -495,10 +490,10 @@ typedef struct cdk_pkt_mdc_s *cdk_pkt_mdc_t;
 
 
 struct cdk_pkt_literal_s {
-    unsigned long len;
+    unsigned int len;
     cdk_stream_t buf;
     int mode;
-    unsigned long timestamp;
+    unsigned int timestamp;
     int namelen;
     char name[1];
 };
@@ -506,7 +501,7 @@ typedef struct cdk_pkt_literal_s *cdk_pkt_literal_t;
 
 
 struct cdk_pkt_compressed_s {
-    unsigned long len;
+    unsigned int len;
     int algorithm;
     cdk_stream_t buf;
 };
@@ -539,7 +534,7 @@ typedef struct cdk_packet_s *cdk_packet_t;
 /* memory routines */
 typedef void (*cdk_log_fnc_t) (void *, int, const char *, va_list);
 void cdk_set_log_level (int lvl);
-void cdk_set_log_handler (cdk_log_fnc_t logfnc, void * opaque);
+void cdk_set_log_handler (cdk_log_fnc_t logfnc, void * opaq);
 const char* cdk_strerror (int ec);
 void cdk_set_malloc_hooks (void *(*new_alloc_func) (size_t n),
                            void *(*new_alloc_secure_func) (size_t n),
@@ -554,7 +549,7 @@ void * cdk_salloc (size_t size, int clear);
 char * cdk_strdup (const char * ptr);
 void cdk_free (void * ptr);
 /* session handle routines */
-cdk_error_t cdk_handle_new( cdk_ctx_t * r_ctx );
+int cdk_handle_new (cdk_ctx_t * r_ctx);
 void cdk_handle_free (cdk_ctx_t c);
 void cdk_handle_set_keydb (cdk_ctx_t hd, cdk_keydb_hd_t db);
 cdk_keydb_hd_t cdk_handle_get_keydb( cdk_ctx_t hd, int type );
@@ -573,8 +568,6 @@ void cdk_handle_set_passphrase_cb( cdk_ctx_t hd,
 #define cdk_handle_set_compress( a, algo, level ) \
   cdk_handle_control( (a), CDK_CTLF_SET, CDK_CTL_COMPRESS, (algo), (level) )
 
-#define cdk_handle_set_blockmode( a, val ) \
-  cdk_handle_control( (a), CDK_CTLF_SET, CDK_CTL_BLOCKMODE_ON, (val) )
 
 /*-- cipher.c --*/
 void cdk_set_progress_handler (void (*cb)(void * hd, unsigned off,
@@ -587,8 +580,7 @@ cdk_error_t cdk_pkt_alloc( cdk_packet_t * r_pkt, int pkttype );
 void cdk_pkt_free( cdk_packet_t pkt );
 void cdk_pkt_release( cdk_packet_t pkt );
 cdk_error_t cdk_pkt_read( cdk_stream_t inp, cdk_packet_t pkt );
-cdk_error_t cdk_pkt_write( cdk_stream_t out, cdk_packet_t pkt );
-cdk_error_t cdk_pkt_write2( cdk_stream_t out, int pkttype, void *pktctx );
+cdk_error_t cdk_pkt_write( cdk_stream_t out, cdk_packet_t pkt );    
 /* sub packet routines */
 cdk_subpkt_t cdk_subpkt_new( size_t size );
 void cdk_subpkt_free( cdk_subpkt_t ctx );
@@ -598,8 +590,7 @@ const unsigned char * cdk_subpkt_get_data( cdk_subpkt_t ctx,
                                           int * r_type, size_t * r_nbytes );
 void cdk_subpkt_init( cdk_subpkt_t node, int type,
                       const void *buf, size_t buflen );
-unsigned char * cdk_userid_pref_get_array( cdk_pkt_userid_t id,
-                                           enum cdk_pref_type_t type,
+unsigned char * cdk_userid_pref_get_array( cdk_pkt_userid_t id, int type,
                                            size_t *ret_len );
 const unsigned char* cdk_key_desig_revoker_walk( cdk_desig_revoker_t root,
                                                  cdk_desig_revoker_t * ctx,
@@ -630,13 +621,13 @@ int cdk_pk_get_nskey (int algo);
 int cdk_pk_get_nsig (int algo);
 int cdk_pk_get_nenc (int algo);
 int cdk_pk_get_fingerprint (cdk_pkt_pubkey_t pk, unsigned char * fpr);
-unsigned long cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
+unsigned int cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
                                             size_t fprlen,
-                                            unsigned long * keyid);
-unsigned long cdk_pk_get_keyid (cdk_pkt_pubkey_t pk, unsigned long * keyid);
-unsigned long cdk_sk_get_keyid (cdk_pkt_seckey_t sk, unsigned long * keyid);
-unsigned long cdk_sig_get_keyid (cdk_pkt_signature_t sig,
-                                 unsigned long * keyid);
+                                            unsigned int * keyid);
+unsigned int cdk_pk_get_keyid (cdk_pkt_pubkey_t pk, unsigned int * keyid);
+unsigned int cdk_sk_get_keyid (cdk_pkt_seckey_t sk, unsigned int * keyid);
+unsigned int cdk_sig_get_keyid (cdk_pkt_signature_t sig,
+                                 unsigned int * keyid);
 cdk_error_t cdk_sk_unprotect( cdk_pkt_seckey_t sk, const char * pw );
 cdk_error_t cdk_sk_protect( cdk_pkt_seckey_t sk, const char * pw );
 cdk_error_t cdk_pk_from_secret_key( cdk_pkt_seckey_t sk,
@@ -662,14 +653,14 @@ cdk_error_t cdk_dek_extract( cdk_dek_t * ret_dek, cdk_ctx_t hd,
 void cdk_dek_set_mdc_flag( cdk_dek_t dek, int val );
 /* string to key */
 cdk_error_t cdk_s2k_new (cdk_s2k_t * ret_s2k, int mode, int algo,
-                         const unsigned char * salt);
+                 const unsigned char * salt);
 void cdk_s2k_free (cdk_s2k_t s2k);
 
 /*-- armor.c --*/
 cdk_error_t cdk_file_armor( cdk_ctx_t hd, const char * file,
                             const char * output );
 cdk_error_t cdk_file_dearmor( const char * file, const char * output );
-int         cdk_armor_filter_use (cdk_stream_t inp);
+cdk_error_t cdk_armor_filter_use (cdk_stream_t inp);
 
 /*-- stream.c --*/
 int cdk_stream_control (cdk_stream_t s, int ctl, int val);
@@ -680,7 +671,7 @@ cdk_stream_t cdk_stream_tmp (void);
 cdk_stream_t cdk_stream_tmp_from_mem (const void * buf, size_t count);
 void cdk_stream_tmp_set_mode (cdk_stream_t s, int val);
 cdk_error_t cdk_stream_flush (cdk_stream_t s);
-cdk_error_t cdk_stream_switch_cache (cdk_stream_t s, int val);
+cdk_error_t cdk_stream_set_cache (cdk_stream_t s, int val);
 cdk_error_t cdk_stream_filter_disable (cdk_stream_t s, int type);
 cdk_error_t cdk_stream_close (cdk_stream_t s);
 unsigned cdk_stream_get_length (cdk_stream_t s);
@@ -692,8 +683,7 @@ int cdk_stream_eof (cdk_stream_t s);
 long cdk_stream_tell (cdk_stream_t s);
 cdk_error_t cdk_stream_seek (cdk_stream_t s, long offset);
 cdk_error_t cdk_stream_set_armor_flag (cdk_stream_t s, int type);
-cdk_error_t cdk_stream_set_literal_flag (cdk_stream_t s, int mode,
-                                         const char * fname);
+cdk_error_t cdk_stream_set_literal_flag (cdk_stream_t s, int mode, const char * fname);
 cdk_error_t cdk_stream_set_cipher_flag (cdk_stream_t s, cdk_dek_t dek,
                                         int use_mdc);
 cdk_error_t cdk_stream_set_compress_flag (cdk_stream_t s, int algo, int level);
@@ -708,19 +698,19 @@ int cdk_stream_peek( cdk_stream_t inp, unsigned char *s, size_t count );
 cdk_error_t cdk_keydb_new( cdk_keydb_hd_t * r_hd, int type, void * data,
                            size_t count);
 cdk_error_t cdk_keydb_open( cdk_keydb_hd_t hd, cdk_stream_t * ret_kr );
-int cdk_keydb_check_sk( cdk_keydb_hd_t hd, unsigned long * keyid );
+int cdk_keydb_check_sk( cdk_keydb_hd_t hd, unsigned int * keyid );
 cdk_error_t cdk_keydb_search_start( cdk_keydb_hd_t hd, int type, void * desc );
 cdk_error_t cdk_keydb_search( cdk_keydb_hd_t hd, cdk_kbnode_t * ret_key );
 void cdk_keydb_free( cdk_keydb_hd_t hd );
-cdk_error_t cdk_keydb_get_bykeyid( cdk_keydb_hd_t hd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_bykeyid( cdk_keydb_hd_t hd, unsigned int * keyid,
                                    cdk_kbnode_t * ret_pk );
 cdk_error_t cdk_keydb_get_byfpr( cdk_keydb_hd_t hd, const unsigned char * fpr,
                                  cdk_kbnode_t * ret_pk );
 cdk_error_t cdk_keydb_get_bypattern( cdk_keydb_hd_t hd, const char * patt,
                                      cdk_kbnode_t * ret_pk );
-cdk_error_t cdk_keydb_get_pk( cdk_keydb_hd_t khd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_pk( cdk_keydb_hd_t khd, unsigned int * keyid,
                       cdk_pkt_pubkey_t* ret_pk );
-cdk_error_t cdk_keydb_get_sk( cdk_keydb_hd_t khd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_sk( cdk_keydb_hd_t khd, unsigned int * keyid,
                               cdk_pkt_seckey_t* ret_sk );
 cdk_error_t cdk_keydb_get_keyblock( cdk_stream_t inp, cdk_kbnode_t * ret_key );
 cdk_error_t cdk_keydb_idx_rebuild( cdk_keydb_hd_t hd );
@@ -782,6 +772,8 @@ cdk_error_t cdk_sklist_write_onepass( cdk_keylist_t skl, cdk_stream_t outp,
 /*-- encrypt.c --*/
 cdk_error_t cdk_stream_encrypt (cdk_ctx_t hd, cdk_strlist_t remusr,
                                 cdk_stream_t inp, cdk_stream_t out);
+cdk_error_t cdk_stream_decrypt (cdk_ctx_t hd, cdk_stream_t inp,
+				cdk_stream_t out);
 cdk_error_t cdk_file_encrypt (cdk_ctx_t hd, cdk_strlist_t remusr,
                       const char * file, const char * output);
 cdk_error_t cdk_file_decrypt (cdk_ctx_t hd, const char * file,
@@ -838,46 +830,15 @@ cdk_error_t cdk_keygen_set_prefs( cdk_keygen_ctx_t hd,
 cdk_error_t cdk_keygen_set_algo_info( cdk_keygen_ctx_t hd, int type,
                                       enum cdk_pk_algo_t algo, int bits );
 void cdk_keygen_set_mdc_feature( cdk_keygen_ctx_t hd, int val );
-int cdk_keygen_set_keyserver_flags( cdk_keygen_ctx_t hd, int no_modify,
-                                    const char *pref_url );
+void cdk_keygen_set_keyserver_flags( cdk_keygen_ctx_t hd, int no_modify,
+                                     const char *pref_url );
 void cdk_keygen_set_expire_date( cdk_keygen_ctx_t hd, int type,
                                  long timestamp );
 void cdk_keygen_set_name( cdk_keygen_ctx_t hd, const char * name );
 void cdk_keygen_set_passphrase( cdk_keygen_ctx_t hd, const char * pass );
 cdk_error_t cdk_keygen_start( cdk_keygen_ctx_t hd );
 cdk_error_t cdk_keygen_save( cdk_keygen_ctx_t hd,
-                             const char * pubf,
-                             const char * secf );
-
-/*-- md.c --*/
-cdk_error_t cdk_md_open( cdk_md_hd_t *r_hd, int algo, unsigned int flags );
-cdk_error_t cdk_md_copy( cdk_md_hd_t *r_new, cdk_md_hd_t md );
-void cdk_md_write( cdk_md_hd_t md, const void *buf, size_t n );
-void cdk_md_close( cdk_md_hd_t md );
-int cdk_md_test_algo( int algo );
-unsigned char * cdk_md_read( cdk_md_hd_t md, int algo );
-int cdk_md_get_algo_dlen( int algo );
-int cdk_md_final( cdk_md_hd_t md );
-int cdk_md_get_algo( cdk_md_hd_t md );
-int cdk_md_get_asnoid( int algo, unsigned char *buf, size_t *n );
-int cdk_md_reset( cdk_md_hd_t md );
-
-/*-- sym-cipher.c --*/
-cdk_error_t cdk_cipher_new( cdk_cipher_hd_t *r_hd, int algo, int pgp_sync );
-cdk_error_t cdk_cipher_open( cdk_cipher_hd_t *r_hd, int algo, int pgp_sync,
-                             const unsigned char * key, size_t keylen,
-                             const unsigned char * ivbuf, size_t ivlen );
-void cdk_cipher_close( cdk_cipher_hd_t hd );
-int cdk_cipher_encrypt( cdk_cipher_hd_t hd, unsigned char * out,
-                        const unsigned char *in, size_t n );
-int cdk_cipher_decrypt( cdk_cipher_hd_t hd, unsigned char * out,
-                        const unsigned char *in, size_t n );
-void cdk_cipher_sync( cdk_cipher_hd_t hd );
-int cdk_cipher_setiv( cdk_cipher_hd_t hd, const unsigned char *iv, size_t n );
-int cdk_cipher_setkey( cdk_cipher_hd_t hd, const unsigned char *key,size_t n );
-int cdk_cipher_get_algo_blklen( int algo );
-int cdk_cipher_get_algo_keylen( int algo );
-int cdk_cipher_test_algo( int algo );
+                     const char * pubf, const char * secf );
 
 #ifdef __cplusplus
 }
