@@ -68,7 +68,7 @@ stream_test_filters (int literal, int compress, int armor, int encrypt)
   if (literal)
     cdk_stream_set_literal_flag (s, 0, "test.asc");
 
-  cdk_stream_switch_cache (s, 1);
+  cdk_stream_set_cache (s, 1);
   /* write a marker packet we won't filter! */
   buf[0] = (0x80 | (10<<2));
   buf[1] = 3;
@@ -76,7 +76,7 @@ stream_test_filters (int literal, int compress, int armor, int encrypt)
   buf[3] = 0x47;
   buf[4] = 0x50;
   cdk_stream_write (s, buf, 5);
-  cdk_stream_switch_cache (s, 0);
+  cdk_stream_set_cache (s, 0);
 
   for (i = 0; i < 512; i++)
     {
@@ -448,11 +448,9 @@ stream_clearsign (char *file)
   cdk_handle_new (&hd);
   cdk_keydb_new (&db, CDK_DBTYPE_SK_KEYRING, "sec.gpg", 7);
   cdk_strlist_add (&locusr, "twoaday@daredevil");
-/*
-  rc = cdk_file_clearsign (hd, locusr, file, "out.asc");
+      //rc = cdk_file_clearsign (hd, locusr, file, "out.asc");
   if (rc)
     printf ("clearsign_file %s: `%s'\n", file, cdk_strerror (rc));
-*/
   cdk_handle_free (hd);
   cdk_strlist_free (locusr);
   return 0;
@@ -548,7 +546,7 @@ int
 main (int argc, char **argv)
 {
   cdk_set_log_level (CDK_LOG_DEBUG);
-  /*return test_stream_kbnode (argc>1? argv[1] : "foo");*/
+  return test_stream_kbnode (argc>1? argv[1] : "foo");
   /*stream_test_filters (1, 1, 1, 1);*/
   /*stream_test_filters_tmp_ascii ();*/
   /*stream_test_filters_tmp_both ();*/
@@ -689,7 +687,7 @@ test_import (int argc, char ** argv)
     cdk_ctx_t hd;
     cdk_keydb_hd_t db;
     int rc;
-    char * s = "/home/twoaday/.gnupg/pubring.cdk";
+    char * s = getenv ("PUBGPG") ? getenv ("PUBGPG") : "pub.gpg";
     const char * pk =
         "-----BEGIN PGP PUBLIC KEY BLOCK-----\n"
         "\n"
@@ -707,20 +705,32 @@ test_import (int argc, char ** argv)
         "-----END PGP PUBLIC KEY BLOCK-----\n";
     unsigned char * out;
     size_t olen = 0;
-    
+
     rc = cdk_handle_new (&hd);
-    assert (!rc);
+    printf ("cdk_handle_new rc %d\n", rc);
+    if (rc != 0)
+      return rc;
+
     rc = cdk_keydb_new (&db, CDK_DBTYPE_PK_KEYRING, s, strlen (s));
-    assert (!rc);
+    printf ("cdk_keydb_new rc %d\n", rc);
+    if (rc != 0)
+      return rc;
+
     cdk_handle_set_keydb (hd, db);
 
     rc = cdk_data_transform (hd, CDK_CRYPTYPE_IMPORT, NULL, NULL,
-                             pk, strlen (pk), &out, &olen, 0);
-    if (!rc)
-        printf ("%s", out);
+			     pk, strlen (pk), &out, &olen, 0);
+    printf ("cdk_data_transform rc %d\n", rc);
+    if (rc != 0)
+      return rc;
+    if (out)
+      printf ("%s", out);
     cdk_handle_free (hd);
     cdk_keydb_free (db);
-    cdk_free (out);
+    if (out)
+      cdk_free (out);
+    if (rc != 0)
+      return 1;
     return 0;
 }
         
@@ -773,9 +783,10 @@ test_keydb_routines (void)
 {
     cdk_keydb_hd_t db;
     cdk_kbnode_t node;
+    char * s = getenv ("PUBGPG") ? getenv ("PUBGPG") : "pub.gpg";
     int rc;
 
-    rc = cdk_keydb_new (&db, CDK_DBTYPE_PK_KEYRING, "pubring.gpg", 11);
+    rc = cdk_keydb_new (&db, CDK_DBTYPE_PK_KEYRING, s, 11);
     if (!rc)
         rc = cdk_keydb_search_start (db, CDK_DBSEARCH_NEXT, NULL);
         /*rc = cdk_keydb_search_start (db, CDK_DBSEARCH_AUTO,
@@ -793,48 +804,28 @@ test_keydb_routines (void)
     if (rc)
         printf ("keydb error `%s'\n", cdk_strerror (rc));
     cdk_keydb_free (db);
-    return rc;
+    if (rc != CDK_Error_No_Key)
+      return 1;
+    return 0;
 }
 
-#if 0
+
 int
 main (int argc, char ** argv)
 {
+  int rc;
+
   /*test_encrypt (argc, argv);*/
   /*test_decrypt (argc, argv);*/
   /*test_sign (argc, argv);*/
-  /*test_verify (argc, argv);*/
-  /*test_import (argc, argv);*/
-  /*test_keydb_routines ();*/
+  /*test_verify (argc, argv);
+  rc = test_import (argc, argv);
+  if (rc != 0)
+    return rc;
+  */
+  rc = test_keydb_routines ();
+  if (rc != 0)
+    return rc;
+
   return 0;
 }
-#endif
-
-#include "../src/random.h"
-int
-main (int argc, char ** argv)
-{
-  unsigned char * p, buf[128];
-  
-  cdk_set_log_level (CDK_LOG_DEBUG);
-  p = cdk_random_bytes (32, CDK_RANDOM_STRONG);
-  if (p)
-    {
-      int i;
-      for (i = 0; i < 32; i++)
-        printf ("%02X", p[i]);
-      cdk_free (p);
-    }
-  printf ("\n");
-  cdk_randomize (buf, 128, CDK_RANDOM_STRONG);
-  {
-    int i;
-    for (i = 0; i < 128; i++)
-      printf ("%02X", buf[i]);
-  }
-  printf ("\n");
-  return 0;
-}
-
-  
-
